@@ -42,7 +42,9 @@ class EmitSeries(object):
                 '%dx%02d' % (season, episode)]
 
     def sequence_identifiers(self, episode):
-        return ['%d' % episode]
+        return ['%d' % episode,
+                '%02d' % episode,
+                '%03d' % episode]
 
     def search_entry(self, series, season, episode, task, rerun=True):
         if series.identified_by == 'ep':
